#define PCI_CONFIG_H
#define PCI_ARCH_SPARC64
#define PCI_OS_OPENBSD
#define PCI_HAVE_PM_OBSD_DEVICE
#define PCI_PATH_OBSD_DEVICE "/dev/pci"
#define PCI_HAVE_PM_DUMP
#define PCI_COMPRESSED_IDS
#define PCI_IDS "pci.ids.gz"
#define PCI_PATH_IDS_DIR "/usr/local/share"
#define PCI_USE_DNS
#define PCI_ID_DOMAIN "pci.id.ucw.cz"
#define PCILIB_VERSION "3.2.1"
